#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 minisat
version:              0.1.3
visibility:           public
id:                   minisat-0.1.3-9XkWdJ6FMf785QRV3wrxiZ
key:                  minisat-0.1.3-9XkWdJ6FMf785QRV3wrxiZ
license:              BSD-3-Clause
synopsis:             A Haskell bundle of the Minisat SAT solver
category:             Logic
abi:                  6b287fa3e4b2499ed5b320307993bab4
exposed:              True
exposed-modules:      MiniSat
import-dirs:          /usr/lib/ghc-9.6.6/site-local/minisat-0.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/minisat-0.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/minisat-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-minisat
hs-libraries:         HSminisat-0.1.3-9XkWdJ6FMf785QRV3wrxiZ
extra-libraries:      stdc++
depends:              async-2.2.5-B3LTRS5ADZ11aNLUYaUoKB base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-minisat/html/minisat.haddock
haddock-html:         /usr/share/doc/haskell-minisat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

